pub struct Transaction { /* private fields */ }Expand description
Request descriptor for one Gingr transaction record by provider ID.
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn new(id: TransactionId) -> Self
pub fn new(id: TransactionId) -> Self
Wraps the Gingr transaction id used to fetch raw payment evidence for review.
Sourcepub fn sensitivity(&self) -> ResponseSensitivity
pub fn sensitivity(&self) -> ResponseSensitivity
Describes whether a response payload should be quarantined from normal logs.