pub struct Transaction { /* private fields */ }Expand description
Request descriptor for one Gingr transaction record by provider ID.
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn new(id: TransactionId) -> Self
pub fn new(id: TransactionId) -> Self
Constructs this typed Gingr boundary value after the caller has chosen the provider input to trust.
Sourcepub fn sensitivity(&self) -> ResponseSensitivity
pub fn sensitivity(&self) -> ResponseSensitivity
Describes whether a response payload should be quarantined from normal logs.